# python-MySQL-
Use query statements to dynamically fetch database column names and generate insert statements
Enter the MySQL database address username and password.
Select the database and table names.
## Insert Functions
First, use a query to retrieve the database columns.
Create a dictionary and generate an insert statement.
## Delete Function
First use the query function to check whether the input column and the keyword of the column exist or not.
Delete the entire row by entering the column name and the keyword of the column to be deleted.
## Query Function
Input the column and the keyword of the column to form a query statement.
## Modify
Input the column name, keyword and content to be changed.
Use the column name and keyword to determine what to change.
Finally, modify the table with the changes.